==> gitlab4j-api-4.19.0-sources.jar: org/gitlab4j/api/models/Namespace.java <==
package org.gitlab4j.api.models;

import org.gitlab4j.api.utils.JacksonJson;

public class Namespace {

    private Integer id;
    private String name;
    private String path;
    private String kind;
    private String fullPath;
    private String avatarUrl;
    private String webUrl;

    public Integer getId() {
        return this.id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return this.name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPath() {
        return this.path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getKind() {
        return kind;
    }

    public void setKind(String kind) {
        this.kind = kind;
    }

    public String getFullPath() {
        return fullPath;
    }

    public void setFullPath(String fullPath) {
        this.fullPath = fullPath;
    }

    public Namespace withId(Integer id) {
        this.id = id;
        return this;
    }

    public Namespace withName(String name) {
        this.name = name;
        return this;
    }

    public Namespace withPath(String path) {
        this.path = path;
        return this;
    }

    public Namespace withKind(String kind) {
        this.kind = kind;
        return this;
    }

    public Namespace withFullPath(String fullPath) {
        this.fullPath = fullPath;
        return this;
    }

    public String getAvatarUrl() {
        return avatarUrl;
    }

    public void setAvatarUrl(String avatarUrl) {
        this.avatarUrl = avatarUrl;
    }

    public String getWebUrl() {
        return webUrl;
    }

    public void setWebUrl(String webUrl) {
        this.webUrl = webUrl;
    }

    @Override
    public String toString() {
        return (JacksonJson.toJsonString(this));
    }
}

==> gitlab4j-api-5.0.1-sources.jar: org/gitlab4j/api/models/Namespace.java <==
package org.gitlab4j.api.models;

import org.gitlab4j.api.utils.JacksonJson;

public class Namespace {

    private Long id;
    private String name;
    private String path;
    private String kind;
    private String fullPath;
    private String avatarUrl;
    private String webUrl;

    public Long getId() {
        return this.id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getName() {
        return this.name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPath() {
        return this.path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getKind() {
        return kind;
    }

    public void setKind(String kind) {
        this.kind = kind;
    }

    public String getFullPath() {
        return fullPath;
    }

    public void setFullPath(String fullPath) {
        this.fullPath = fullPath;
    }

    public Namespace withId(Long id) {
        this.id = id;
        return this;
    }

    public Namespace withName(String name) {
        this.name = name;
        return this;
    }

    public Namespace withPath(String path) {
        this.path = path;
        return this;
    }

    public Namespace withKind(String kind) {
        this.kind = kind;
        return this;
    }

    public Namespace withFullPath(String fullPath) {
        this.fullPath = fullPath;
        return this;
    }

    public String getAvatarUrl() {
        return avatarUrl;
    }

    public void setAvatarUrl(String avatarUrl) {
        this.avatarUrl = avatarUrl;
    }

    public String getWebUrl() {
        return webUrl;
    }

    public void setWebUrl(String webUrl) {
        this.webUrl = webUrl;
    }

    @Override
    public String toString() {
        return (JacksonJson.toJsonString(this));
    }
}
